"""
Constants
"""
EMPTY_REPO_RE = r"fatal: your current branch '\w+' does not have any commits yet"
UNKNOWN_REV_RE = r"fatal: ambiguous argument '\w+': unknown revision or path not in the working tree."
